@@ -2,8 +2,8 @@
  *
  * Name:	skgepnmi.h
  * Project:	Gigabit Ethernet Adapters, PNMI-Module
- * Version:	$Revision: 2.20 $
- * Date:	$Date: 2008/03/06 14:16:17 $
+ * Version:	$Revision: 2.26 $
+ * Date:	$Date: 2010/04/29 14:26:52 $
  * Purpose:	Defines for Private Network Management Interface
  *
  ****************************************************************************/
@@ -34,7 +34,9 @@
 #include "h/sktimer.h"
 #include "h/sktwsi.h"
 #include "h/skaddr.h"
+#ifndef SK_NO_RLMT
 #include "h/skrlmt.h"
+#endif
 #include "h/skvpd.h"
 
 /*
@@ -232,6 +234,7 @@
 #define OID_SKGE_INTERMEDIATE_SUPPORT		0xFF010160
 #define OID_SKGE_SET_TEAM_MAC_ADDRESS		0xFF010161
 #define OID_SKGE_DEVICE_INFORMATION 		0xFF010162
+#define OID_SKGE_MACSEC_CONFIGURATION 		0xFF010163
 
 #define OID_SKGE_SPEED_CAP				0xFF010170
 #define OID_SKGE_SPEED_MODE				0xFF010171
@@ -429,6 +432,12 @@
 #define OID_SKGE_ASF_DASH_USER_DAT		0xFF020245
 #define OID_SKGE_ASF_DASH_BUSY			0xFF020246
 #define OID_SKGE_ASF_DASH_MAX_USER		0xFF020247
+#define OID_SKGE_ASF_DASH_IP_INFO		0xFF020300
+#define OID_SKGE_ASF_DASH_IP_INFO_EXT		0xFF020301
+#define OID_SKGE_ASF_DASH_SPECIAL_ACTION	0xFF020302
+#define OID_SKGE_ASF_DASH_OS_VERSION_INFO_SET	0xFF020303
+
+
 #endif /* SK_ASF */
 
 /* VCT struct to store a backup copy of VCT data after a port reset. */
@@ -821,6 +830,7 @@ typedef struct s_PnmiConf {
 	SK_U8			ConfSpeedStatus;
 } SK_PNMI_CONF;
 
+#ifndef SK_NO_RLMT
 typedef struct s_PnmiRlmt {
 	SK_U32			RlmtIndex;
 	SK_U32			RlmtStatus;
@@ -837,6 +847,7 @@ typedef struct s_PnmiRlmtMonitor {
 	SK_U64			RlmtMonitorTimestamp;
 	SK_U8			RlmtMonitorAdmin;
 } SK_PNMI_RLMT_MONITOR;
+#endif
 
 typedef struct s_PnmiRequestStatus {
 	SK_U32			ErrorStatus;
@@ -874,6 +885,7 @@ typedef struct s_PnmiStrucData {
 	SK_PNMI_CHECKSUM	Checksum[SK_PNMI_CHECKSUM_ENTRIES];
 	SK_PNMI_STAT	Stat[SK_PNMI_MAC_ENTRIES];
 	SK_PNMI_CONF	Conf[SK_PNMI_MAC_ENTRIES];
+#ifndef SK_NO_RLMT
 	SK_U8			RlmtMode;
 	SK_U32			RlmtPortNumber;
 	SK_U8			RlmtPortActive;
@@ -885,6 +897,7 @@ typedef struct s_PnmiStrucData {
 	SK_PNMI_RLMT	Rlmt[SK_MAX_MACS];
 	SK_U32			RlmtMonitorNumber;
 	SK_PNMI_RLMT_MONITOR	RlmtMonitor[SK_PNMI_MONITOR_ENTRIES];
+#endif
 	SK_U32			TrapNumber;
 	SK_U8			Trap[SK_PNMI_TRAP_QUEUE_LEN];
 	SK_U64			TxSwQueueLen;
