@@ -600,12 +600,16 @@ int SkGeSetSettings(struct net_device *dev,
 	
 		if (Ret != SK_PNMI_ERR_OK) {
 			return -EINVAL;
+		} else {
+		/* Set the parameter */
+			pAC->LinkInfo[port].PLinkModeConf = (int) *Buf;
 		}
 	} else if (ecmd->autoneg == AUTONEG_ENABLE) {
 	/* Set default values */
 		*Buf = (char) SK_LMODE_AUTOBOTH;
 		Ret = SkPnmiSetVar(pAC, pAC->IoBase, OID_SKGE_LINK_MODE, 
 					&Buf, &Len, Instance, pNet->NetNr);
+		pAC->LinkInfo[port].PLinkModeConf = SK_LMODE_AUTOBOTH;
 	}
 
 	if ((ecmd->speed == SPEED_1000) ||
@@ -627,11 +631,14 @@ int SkGeSetSettings(struct net_device *dev,
 	
 		if (Ret != SK_PNMI_ERR_OK) {
 			return -EINVAL;
+		} else {
+			pAC->LinkInfo[port].PLinkSpeed = (int) *Buf;
 		}
 	} else if (ecmd->autoneg == AUTONEG_ENABLE) {
 		*Buf = (char) SK_LSPEED_AUTO;
 		Ret = SkPnmiSetVar(pAC, pAC->IoBase, OID_SKGE_SPEED_MODE, 
 					&Buf, &Len, Instance, pNet->NetNr);
+		pAC->LinkInfo[port].PLinkSpeed = SK_LSPEED_AUTO;
 	} else {
 		return -EINVAL;
 	}
