@@ -2,8 +2,8 @@
  *
  * Name:	skgemib.c
  * Project:	Gigabit Ethernet Adapters, PNMI-Module
- * Version:	$Revision: 2.14 $
- * Date:	$Date: 2008/03/06 14:15:53 $
+ * Version:	$Revision: 2.19 $
+ * Date:	$Date: 2010/04/29 14:27:32 $
  * Purpose:	Private Network Management Interface Management Database
  *
  ****************************************************************************/
@@ -44,21 +44,23 @@ PNMI_STATIC int MacPrivateConf(SK_AC *pAC, SK_IOC IoC, int action, SK_U32 Id,
 PNMI_STATIC int MacPrivateStat(SK_AC *pAC, SK_IOC IoC, int action, SK_U32 Id,
 	char *pBuf, unsigned int *pLen, SK_U32 Instance,
 	unsigned int TableIndex, SK_U32 NetIndex);
-PNMI_STATIC int Monitor(SK_AC *pAC, SK_IOC IoC, int action,
-	SK_U32 Id, char *pBuf, unsigned int *pLen, SK_U32 Instance,
-	unsigned int TableIndex, SK_U32 NetIndex);
 PNMI_STATIC int OidStruct(SK_AC *pAC, SK_IOC IoC, int action, SK_U32 Id,
 	char *pBuf, unsigned int *pLen, SK_U32 Instance,
 	unsigned int TableIndex, SK_U32 NetIndex);
 PNMI_STATIC int Perform(SK_AC *pAC, SK_IOC IoC, int action, SK_U32 Id,
 	char *pBuf, unsigned int* pLen, SK_U32 Instance,
 	unsigned int TableIndex, SK_U32 NetIndex);
+#ifndef SK_NO_RLMT
 PNMI_STATIC int Rlmt(SK_AC *pAC, SK_IOC IoC, int action, SK_U32 Id,
 	char *pBuf, unsigned int *pLen, SK_U32 Instance,
 	unsigned int TableIndex, SK_U32 NetIndex);
 PNMI_STATIC int RlmtStat(SK_AC *pAC, SK_IOC IoC, int action, SK_U32 Id,
 	char *pBuf, unsigned int *pLen, SK_U32 Instance,
 	unsigned int TableIndex, SK_U32 NetIndex);
+PNMI_STATIC int Monitor(SK_AC *pAC, SK_IOC IoC, int action,
+	SK_U32 Id, char *pBuf, unsigned int *pLen, SK_U32 Instance,
+	unsigned int TableIndex, SK_U32 NetIndex);
+#endif
 PNMI_STATIC int SensorStat(SK_AC *pAC, SK_IOC IoC, int action, SK_U32 Id,
 	char *pBuf, unsigned int *pLen, SK_U32 Instance,
 	unsigned int TableIndex, SK_U32 NetIndex);
@@ -250,6 +252,23 @@ PNMI_STATIC const SK_PNMI_TAB_ENTRY IdTable[] = {
 		0,
 		0,
 		SK_PNMI_RW, PowerManagement, 0},
+#ifdef SK_POWER_MGMT_EX
+	{OID_PM_PARAMETERS,
+		0,
+		0,
+		0,
+		SK_PNMI_RW, PowerManagement, 0},
+	{OID_PM_ADD_WOL_PATTERN,
+		0,
+		0,
+		0,
+		SK_PNMI_WO, PowerManagement, 0},
+	{OID_PM_REMOVE_WOL_PATTERN,
+		0,
+		0,
+		0,
+		SK_PNMI_WO, PowerManagement, 0},
+#endif /* SK_POWER_MGMT_EX */
 #endif /* SK_POWER_MGMT */
 #ifdef SK_DIAG_SUPPORT
 	{OID_SKGE_DIAG_MODE,
@@ -464,11 +483,31 @@ PNMI_STATIC const SK_PNMI_TAB_ENTRY IdTable[] = {
 		0,
 		0,
 		SK_PNMI_RO, Asf, 0},
+	{OID_SKGE_ASF_DASH_IP_INFO,
+		0,
+		0,
+		0,
+		SK_PNMI_RO, Asf, 0},
 	{OID_SKGE_ASF_DASH_BUSY,
 		0,
 		0,
 		0,
 		SK_PNMI_RO, Asf, 0},
+	{OID_SKGE_ASF_DASH_IP_INFO_EXT,
+		0,
+		0,
+		0,
+		SK_PNMI_RW, Asf, 0},
+	{OID_SKGE_ASF_DASH_OS_VERSION_INFO_SET,
+		0,
+		0,
+		0,
+		SK_PNMI_RW, Asf, 0},
+	{OID_SKGE_ASF_DASH_SPECIAL_ACTION,
+		0,
+		0,
+		0,
+		SK_PNMI_RO, Asf, 0},
 #endif /* SK_ASF */
 	{OID_SKGE_MDB_VERSION,
 		1,
@@ -1172,6 +1211,7 @@ PNMI_STATIC const SK_PNMI_TAB_ENTRY IdTable[] = {
 		0,
 		SK_PNMI_MAI_OFF(TrapNumber),
 		SK_PNMI_RO, General, 0},
+#ifndef SK_NO_RLMT
 	{OID_SKGE_RLMT_MODE,
 		1,
 		0,
@@ -1272,6 +1312,7 @@ PNMI_STATIC const SK_PNMI_TAB_ENTRY IdTable[] = {
 		sizeof(SK_PNMI_RLMT_MONITOR),
 		SK_PNMI_OFF(RlmtMonitor) + SK_PNMI_MON_OFF(RlmtMonitorAdmin),
 		SK_PNMI_RW, Monitor, 0},
+#endif
 	{OID_SKGE_MTU,
 		1,
 		0,
